@@ -107,14 +107,3 @@ gcal_calendar_management_page_switch_page (GcalCalendarManagementPage *self,
 
   g_signal_emit (self, signals[SWITCH_PAGE], 0, page_name, calendar);
 }
-
-HdyHeaderBar*
-gcal_calendar_management_page_get_titlebar (GcalCalendarManagementPage *self)
-{
-  GtkWidget *toplevel;
-
-  toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-  g_assert (toplevel != NULL);
-
-  return gcal_calendar_management_dialog_get_titlebar (GCAL_CALENDAR_MANAGEMENT_DIALOG (toplevel));
-}
