@@ -48,7 +48,7 @@
 
 struct _GcalEventEditorDialog
 {
-  GtkDialog         parent;
+  AdwWindow               parent;
 
   GtkWidget              *cancel_button;
   GtkWidget              *delete_button;
@@ -85,11 +85,7 @@ struct _GcalEventEditorDialog
   gboolean          writable;
 };
 
-static void          on_calendar_selected_action_cb              (GSimpleAction      *menu_item,
-                                                                  GVariant           *value,
-                                                                  gpointer            user_data);
-
-G_DEFINE_TYPE (GcalEventEditorDialog, gcal_event_editor_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE (GcalEventEditorDialog, gcal_event_editor_dialog, ADW_TYPE_WINDOW)
 
 enum
 {
@@ -109,11 +105,6 @@ enum
 static guint signals[NUM_SIGNALS] = { 0, };
 static GParamSpec* properties[N_PROPS] = { NULL, };
 
-static const GActionEntry action_entries[] =
-{
-  { "select-calendar", on_calendar_selected_action_cb, "s" },
-};
-
 
 /*
  * Auxiliary methods
@@ -550,6 +541,11 @@ gcal_event_editor_dialog_finalize (GObject *object)
 static void
 gcal_event_editor_dialog_constructed (GObject* object)
 {
+  const GActionEntry action_entries[] =
+  {
+    { "select-calendar", on_calendar_selected_action_cb, "s" },
+  };
+
   GcalEventEditorDialog *self;
 
   self = GCAL_EVENT_EDITOR_DIALOG (object);
@@ -559,9 +555,6 @@ gcal_event_editor_dialog_constructed (GObject* object)
 
   gtk_window_set_title (GTK_WINDOW (object), "");
 
-  /* titlebar */
-  gtk_window_set_titlebar (GTK_WINDOW (object), self->titlebar);
-
   /* Actions */
   self->action_group = g_simple_action_group_new ();
   g_action_map_add_action_entries (G_ACTION_MAP (self->action_group),
