@@ -601,11 +601,12 @@ gcal_agenda_view_remove_event (GcalTimelineSubscriber *subscriber,
 
 static void
 gcal_agenda_view_update_event (GcalTimelineSubscriber *subscriber,
+                               GcalEvent              *old_event,
                                GcalEvent              *event)
 {
   GCAL_ENTRY;
 
-  gcal_agenda_view_remove_event (subscriber, event);
+  gcal_agenda_view_remove_event (subscriber, old_event);
   gcal_agenda_view_add_event (subscriber, event);
 
   GCAL_EXIT;
