@@ -206,7 +206,7 @@ update_header_labels (GcalMonthView *self)
     }
   else
     {
-      month_string = g_strdup_printf("%s - %s ",
+      month_string = g_strdup_printf("%s–%s",
                                      gcal_get_month_name (g_date_time_get_month (first_visible_date) -1),
                                      gcal_get_month_name (g_date_time_get_month (last_visible_date) - 1));
     }
@@ -217,7 +217,7 @@ update_header_labels (GcalMonthView *self)
     }
   else
     {
-      year_string = g_strdup_printf ("%d - %d",
+      year_string = g_strdup_printf ("%d–%d",
                                     g_date_time_get_year (first_visible_date),
                                     g_date_time_get_year (last_visible_date));
     }
@@ -330,7 +330,7 @@ move_bottom_row_to_top (GcalMonthView *self)
 
   new_range = gcal_range_new_take (g_date_time_add_weeks (first_row_range_start, -1),
                                    g_date_time_ref (first_row_range_start),
-                                   GCAL_RANGE_DATE_ONLY);
+                                   GCAL_RANGE_DEFAULT);
 
 #ifdef GCAL_ENABLE_TRACE
     {
@@ -364,7 +364,7 @@ move_top_row_to_bottom (GcalMonthView *self)
 
   new_range = gcal_range_new_take (g_date_time_ref (last_row_range_end),
                                    g_date_time_add_weeks (last_row_range_end, 1),
-                                   GCAL_RANGE_DATE_ONLY);
+                                   GCAL_RANGE_DEFAULT);
 
 #ifdef GCAL_ENABLE_TRACE
     {
@@ -414,12 +414,13 @@ update_week_ranges (GcalMonthView *self,
    */
   n_weeks_before = N_ROWS_PER_PAGE * (N_PAGES - 1) / 2;
 
-  current_range = gcal_timeline_subscriber_get_range (GCAL_TIMELINE_SUBSCRIBER (self));
   current_date = g_steal_pointer (&self->date);
+  if (current_date)
+    current_range = gcal_timeline_subscriber_get_range (GCAL_TIMELINE_SUBSCRIBER (self));
 
   gcal_set_date_time (&self->date, new_date);
 
-  if (gcal_range_contains_datetime (current_range, new_date))
+  if (current_range && gcal_range_contains_datetime (current_range, new_date))
     {
       g_autoptr (GcalRange) row_range = NULL;
       GcalMonthViewRow *row;
@@ -454,8 +455,8 @@ update_week_ranges (GcalMonthView *self,
 
           date = g_date_time_add_weeks (self->date, i - n_weeks_before);
           week_start = gcal_date_time_get_start_of_week (date);
-          week_end = gcal_date_time_get_end_of_week (date);
-          range = gcal_range_new (week_start, week_end, GCAL_RANGE_DATE_ONLY);
+          week_end = g_date_time_add_weeks (week_start, 1);
+          range = gcal_range_new (week_start, week_end, GCAL_RANGE_DEFAULT);
 
           row = g_ptr_array_index (self->week_rows, i);
           gcal_month_view_row_set_range (row, range);
@@ -1519,6 +1520,7 @@ gcal_month_view_dispose (GObject *object)
   g_clear_object (&self->kinetic_scroll_animation);
   g_clear_object (&self->row_offset_animation);
 
+  g_clear_pointer (&self->overflow.popover, gtk_widget_unparent);
   g_clear_pointer (&self->header, gtk_widget_unparent);
   g_clear_pointer (&self->week_rows, g_ptr_array_unref);
 
