@@ -250,6 +250,7 @@ on_click_gesture_released_cb (GtkGestureClick *click_gesture,
                               GcalWeekGrid    *self)
 {
   g_autoptr (GDateTime) week_start = NULL;
+  g_autoptr (GcalRange) range = NULL;
   g_autoptr (GDateTime) start = NULL;
   g_autoptr (GDateTime) end = NULL;
   GtkAllocation alloc;
@@ -319,7 +320,8 @@ on_click_gesture_released_cb (GtkGestureClick *click_gesture,
                                     &out_x,
                                     &out_y);
 
-  gcal_view_create_event (GCAL_VIEW (weekview), start, end, out_x, out_y);
+  range = gcal_range_new (start, end, GCAL_RANGE_DEFAULT);
+  gcal_view_create_event (GCAL_VIEW (weekview), range, out_x, out_y);
 
   gtk_event_controller_set_propagation_phase (self->motion_controller, GTK_PHASE_NONE);
 }
@@ -956,7 +958,7 @@ void
 gcal_week_grid_remove_event (GcalWeekGrid *self,
                              const gchar  *uid)
 {
-  GPtrArray *widgets;
+  g_autoptr (GPtrArray) widgets = NULL;
   guint i;
 
   g_return_if_fail (GCAL_IS_WEEK_GRID (self));
@@ -977,8 +979,6 @@ gcal_week_grid_remove_event (GcalWeekGrid *self,
       gcal_range_tree_remove_range (self->events, gcal_event_get_range (event), data);
       gtk_widget_queue_allocate (GTK_WIDGET (self));
     }
-
-  g_clear_pointer (&widgets, g_ptr_array_unref);
 }
 
 GList*
@@ -1015,3 +1015,4 @@ gcal_week_grid_set_date (GcalWeekGrid *self,
   gtk_widget_queue_resize (GTK_WIDGET (self));
   gtk_widget_queue_draw (GTK_WIDGET (self));
 }
+
