@@ -18,7 +18,6 @@
 
 #define G_LOG_DOMAIN      "GcalWeatherService"
 
-#include <geocode-glib/geocode-glib.h>
 #include <geoclue.h>
 #include <string.h>
 #include <math.h>
@@ -743,7 +742,8 @@ on_gclue_simple_creation_cb (GClueSimple        *_source,
     {
       g_assert_null (self->location_service);
 
-      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED) &&
+          !(g_dbus_error_is_remote_error (error) && strcmp (g_dbus_error_get_remote_error (error), "org.freedesktop.DBus.Error.AccessDenied") == 0))
         g_warning ("Could not create GCLueSimple: %s", error->message);
 
       GCAL_RETURN ();
@@ -1033,6 +1033,37 @@ gcal_weather_service_set_time_zone (GcalWeatherService *self,
   g_object_notify (G_OBJECT (self), "time-zone");
 }
 
+/**
+ * gcal_weather_service_get_weather_info_for_date:
+ * @self: The #GcalWeatherService instance.
+ * @date: The #GDate for which to get the current forecast.
+ *
+ * Retrieves the available weather information for @date.
+ *
+ * Returns: (transfer none)(nullable): a #GcalWeatherInfo
+ */
+GcalWeatherInfo*
+gcal_weather_service_get_weather_info_for_date (GcalWeatherService *self,
+                                                GDate              *date)
+{
+  g_return_val_if_fail (GCAL_IS_WEATHER_SERVICE (self), NULL);
+
+  for (guint i = 0; self->weather_infos && i < self->weather_infos->len; i++)
+    {
+      GcalWeatherInfo *info;
+      GDate weather_date;
+
+      info = g_ptr_array_index (self->weather_infos, i);
+
+      gcal_weather_info_get_date (info, &weather_date);
+
+      if (g_date_compare (&weather_date, date) == 0)
+        return info;
+    }
+
+  return NULL;
+}
+
 /**
  * gcal_weather_service_get_weather_infos:
  * @self: The #GcalWeatherService instance.
@@ -1177,28 +1208,3 @@ gcal_weather_service_stop (GcalWeatherService *self)
 
   GCAL_EXIT;
 }
-
-/**
- * gcal_weather_service_connect_widget:
- * @old_service: The views weather service field.
- * @new_service: (nullable): The new weather service to use.
- * @update_func: The function to call after updating weather.
- * @weather_changed_cb: The views "weather-changed" handler
- * @data: The data to pass to @update_func and @weather_changed_cb
- *
- * Internal implementation helper for widgets.
- */
-void
-gcal_weather_service_connect_widget (GcalWeatherService    *self,
-                                     GcalWeatherUpdateFunc  update_func,
-                                     GCallback              weather_changed_cb,
-                                     GtkWidget             *data)
-{
-  g_return_if_fail (GCAL_IS_WEATHER_SERVICE (self));
-  g_return_if_fail (update_func != NULL);
-  g_return_if_fail (weather_changed_cb != NULL);
-  g_return_if_fail (GTK_IS_WIDGET (data));
-
-  g_signal_connect_object (self, "weather-changed", weather_changed_cb, data, 0);
-  update_func (data);
-}
